// Géry Casiez

import { io } from "socket.io-client";


//disabling the multi touch events on iPhone
document.addEventListener('gesturestart', (e) => e.preventDefault());

//do it once the page is completely
document.addEventListener("DOMContentLoaded", function() {
    let elt = document.body;
    elt.addEventListener("touchstart", function(evt) { 
        let x = evt.touches.item(0).clientX;
        let y = evt.touches.item(0).clientY;
        socket.emit("touchstart", x, y);
    });
    
    elt.addEventListener("touchmove", function(evt) { 
        let x = evt.touches.item(0).clientX;
        let y = evt.touches.item(0).clientY;
        socket.emit("touchmove", x, y);
        //appendMessage(x + " " + y);
        
        let dot = document.getElementsByClassName("indicatorDot2")[0];
        dot.setAttribute('style', "left:" + (x - 100) + "px;" +
        "top:" + (y - 100) + "px;");
    });
    
    elt.addEventListener("touchend", function(evt) {
        socket.emit("touchend");
        
        let dot = document.getElementsByClassName("indicatorDot2")[0];
        dot.setAttribute('style', "left:-50%; top:-50%;");
    });

    const status = document.getElementById("status");
    const messages = document.getElementById("messages");
    
    const appendMessage = (content) => {
        const item = document.createElement("li");
        item.textContent = content;
        messages.appendChild(item);
    };
    
    const socket = io({
        // Socket.IO options
    });
    
    socket.on("connect", () => {
        status.innerText = "Connected";
        appendMessage(`event: connect | session id: ${socket.id}`);
    });
    
    socket.on("connect_error", (err) => {
        appendMessage(`event: connect_error | reason: ${err.message}`);
    });
    
    socket.on("disconnect", (reason) => {
        status.innerText = "Disconnected";
        appendMessage(`event: disconnect | reason: ${reason}`);
    });
    
    socket.onAny((event, ...args) => {
        appendMessage(`event: ${event} | arguments: ${args}`);
    });

    function addOrientationListener() {
        window.addEventListener('deviceorientation',(event) => {
            let rotation_degrees = event.alpha;
            let frontToBack_degrees = event.beta;
            let leftToRight_degrees = event.gamma;
            
            if (rotation_degrees > 200) rotation_degrees -= 360;
            socket.emit("orientation", rotation_degrees, frontToBack_degrees);
            
            let dot = document.getElementsByClassName("indicatorDot")[0];
            dot.setAttribute('style', "left:" + (50 - rotation_degrees) + "%;" +
            "top:" + (50 - frontToBack_degrees) + "%;");
            
        });
    }

    function getOrientation(){
        // iOS requires to request permission
        if (whichOS() == "iOS") {
            DeviceMotionEvent.requestPermission().then(response => {
                if (response == 'granted') {
                    addOrientationListener();
                }
            });
        } else {
            addOrientationListener();
        }
    }

    const buttonGetOrientation = document.getElementById("getOrientationButton");

    buttonGetOrientation.addEventListener('click', (e) => {
        getOrientation()
    });

});


//determine the OS of the client
function whichOS() {
    let OSName = "Unknown OS";
    if (navigator.userAgent.indexOf("Win") != -1) OSName = "Windows";
    if (navigator.userAgent.indexOf("Mac") != -1) OSName = "Macintosh";
    if (navigator.userAgent.indexOf("Linux") != -1) OSName = "Linux";
    if (navigator.userAgent.indexOf("Android") != -1) OSName = "Android";
    if (navigator.userAgent.indexOf("like Mac") != -1) OSName = "iOS";
    return OSName;
}

//determine the browser of the client
function getBrowser() {
    if (navigator.userAgent.indexOf("Edg") > -1 && navigator.appVersion.indexOf('Edg') > -1 ) {
        return 'Edge';
    }
    else if(navigator.userAgent.indexOf("Opera") != -1 || navigator.userAgent.indexOf('OPR') != -1 ){
        return 'Opera';
    }
    else if(navigator.userAgent.indexOf("Chrome") != -1){
        return 'Chrome';
    }
    else if(navigator.userAgent.indexOf("Safari") != -1){
        return 'Safari';
    }
    else if(navigator.userAgent.indexOf("Firefox") != -1) {
        return 'Firefox';
    }
    else if((navigator.userAgent.indexOf("MSIE") != -1)) {
        return 'Interet Explorer';
    }  
    else {
        return 'unknown';
    }
}
