// Géry Casiez

import { readFileSync } from "fs";
import { createServer } from "https";
import { Server } from "socket.io";
import * as path from "path";

const httpServer = createServer({
    // We have to create a https localserver to allow
    // the client to use orientation information
    // Certificates are created using the command
    // openssl req -new -x509 -keyout key.pem -out server.pem -days 365 -nodes
    key: readFileSync("key.pem"),
    cert: readFileSync("server.pem")
}, (req, res) => {
 
    try {
        const file = path.join("../clients/dist", req.url.substring(1));
        console.log(file);
        const content = readFileSync(file);
        const length = Buffer.byteLength(content);
        
        res.writeHead(200, {
            "Content-Type": "text/html",
            "Content-Length": length,
        });
        res.end(content);
    } catch (error) {
        console.log(error);
        res.writeHead(404);
        res.end("Not found");
        return;
    }
});

const io = new Server(httpServer, {
    key: readFileSync("key.pem"),
    cert: readFileSync("server.pem")
});

var desktopID = 0;

io.on("connection", (socket) => {
    console.log(`connect ${socket.id}`);

    socket.on("disconnect", (reason) => {
        console.log(`disconnect ${socket.id} due to ${reason}`);
    });

    socket.on("registerDesktopID", (id => {
        desktopID = id;
    })); 
    
    // Get message from mobile with the orientation
    socket.on("orientation", ((x, y) => {
        console.log(x, y);
        // if a desktop is registered, transmit the message
        if (desktopID != 0)
            io.to(desktopID).emit("orientation", x, y);
    })); 

    // Get message from mobile with the touch info
    socket.on("touchstart", ((x, y) => {
        //console.log(x, y);
        if (desktopID != 0)
            io.to(desktopID).emit("touchstart", x, y);
    })); 

    socket.on("touchmove", ((x, y) => {
        //console.log(x, y);
        if (desktopID != 0)
            io.to(desktopID).emit("touchmove", x, y);
    })); 

    socket.on("touchend", (() => {
        if (desktopID != 0)
            io.to(desktopID).emit("touchend");
    })); 


});

httpServer.listen(3000);
